@@ -19,7 +19,8 @@ from .benchmark import Benchmark
               show_default=True,
               multiple=True,
               type=click.Choice(['dane', 'dane-no-misc', 'ddt-pos', 'ddt-dep',
-                                 'angry-tweets', 'twitter-sent', 'dkhate',
+                                 'angry-tweets', 'twitter-sent',
+                                 'twitter-subj', 'europarl-subj', 'dkhate',
                                  'europarl1', 'europarl2', 'lcc1', 'lcc2']),
               help='The name of the benchmark dataset. If not specified then '
                    'all datasets will be benchmarked.')
