@@ -131,6 +131,44 @@ def load_dkhate() -> Tuple[dict, dict, dict, dict]:
     return X_train, X_test, y_train, y_test
 
 
+def load_twitter_subj() -> Tuple[dict, dict, dict, dict]:
+    '''Load the TwitterSubj dataset.
+
+    Returns:
+        tuple:
+            Four dicts, `X_train`, `X_test`, `y_train` and `y_test`, where
+            `X_train` and `X_test` corresponds to the feature matrices for the
+            training and test split, respectively, and `y_train` and `y_test`
+            contains the target vectors.
+    '''
+    base_url = ('https://raw.githubusercontent.com/saattrupdan/ScandEval/'
+                'main/datasets/twitter_subj/')
+    train_url = base_url + 'train.jsonl'
+    test_url = base_url + 'test.jsonl'
+    X_train, y_train = _get_dataset_from_url(train_url, 'tweet', 'label')
+    X_test, y_test = _get_dataset_from_url(test_url, 'tweet', 'label')
+    return X_train, X_test, y_train, y_test
+
+
+def load_europarl_subj() -> Tuple[dict, dict, dict, dict]:
+    '''Load the EuroparlSubj dataset.
+
+    Returns:
+        tuple:
+            Four dicts, `X_train`, `X_test`, `y_train` and `y_test`, where
+            `X_train` and `X_test` corresponds to the feature matrices for the
+            training and test split, respectively, and `y_train` and `y_test`
+            contains the target vectors.
+    '''
+    base_url = ('https://raw.githubusercontent.com/saattrupdan/ScandEval/'
+                'main/datasets/europarl_subj/')
+    train_url = base_url + 'train.jsonl'
+    test_url = base_url + 'test.jsonl'
+    X_train, y_train = _get_dataset_from_url(train_url, 'text', 'label')
+    X_test, y_test = _get_dataset_from_url(test_url, 'text', 'label')
+    return X_train, X_test, y_train, y_test
+
+
 def load_europarl1() -> Tuple[dict, dict, dict, dict]:
     '''Load the Europarl1 dataset.
 
